@@ -153,11 +153,22 @@ class Form(Config):
         self._initialized = False
         """Flag to indicate that the form has been setup"""
 
+        self._buttons = self.get_buttons()
+        """Buttons of the form"""
         self._fields = self.get_fields()
         self._initialized = True
         """Dictionary with all fields in the form. The name of the field is the
         key in the dictionary"""
 
+    def get_buttons(self, root=None):
+        # Get all Buttons for the form.
+        buttons = []
+        if root is None:
+            root = self._tree
+        for b in root.findall('.//button'):
+            buttons.append(b)
+        return buttons
+
     def get_pages(self, root=None):
         # Get all fields for the form.
         pages = []
@@ -396,6 +407,26 @@ class Renderer(Config):
         - Textarea
         - HTML
         """
+        self.label_position = "top"
+        """Optional. If defined the label will placed left, top
+        or right to the field.  Defaults to top"""
+        self.label_align = "left"
+        """Optional. If defined the label will be aligned left or right,
+        Defaults to left This only applies for lables which are
+        positioned on the left or right side"""
+        self.label_width = 2
+        """Optional. If defined the label will have the defined width.
+        Defaults to 2 cols. The Fieldwidth will be reduced by the label
+        width. This only applies for lables which are positioned on the
+        left or right side."""
+        label_config = entity.find('label')
+        if label_config is not None:
+            self.label_position = label_config.attrib.get("position") or "top"
+            if self.label_position == "left":
+                self.label_align = label_config.attrib.get("align") or "right"
+            elif self.label_position == "right":
+                self.label_align = label_config.attrib.get("align") or "left"
+            self.label_width = int(label_config.attrib.get("width") or 2)
 
         # Warning! The body of the renderer may include all valid and
         # invalid html data including scripting. Use with caution here as
@@ -404,7 +435,7 @@ class Renderer(Config):
         self.body = None
         """The body attribute is currently only used by the HTML
         Renderer and has the content to be rendererd."""
-        if len(entity) > 0:
+        if self.render_type == "html" and len(entity) > 0:
             self.body = ET.tostring(entity[0], method="html")
 
     def __getattr__(self, name):
