@@ -1,7 +1,6 @@
 import logging
 import datetime
 import sqlalchemy as sa
-from formencode import htmlfill, variabledecode
 from formbar.renderer import FormRenderer, get_renderer
 from formbar.rules import Rule, Parser
 
@@ -141,6 +140,10 @@ class Form(object):
         self.loaded_data = self.serialize(self._get_data_from_item())
         """This is the initial data loaded from the given item. Used to
         render the readonly forms"""
+        self.merged_data = {}
+        """This is merged date from the initial data loaded from the
+        given item. And userprovied data. The data is available after
+        rendering the form"""
 
     def _set_current_field_data(self, data):
         for key in self.fields:
@@ -201,8 +204,7 @@ class Form(object):
 
     def serialize(self, data):
         """Returns a dictionary with serialized data from the forms
-        item.  The return dictionary is suitable for htmlfill to prefill
-        the rendered form. The dictionary will include all attributes
+        item.  The dictionary will include all attributes
         and relations values of the items. The key in the dictionary is
         the name of the relation/attribute. In case of relations the
         value in the dictionary is the "id" value of the related item.
@@ -317,6 +319,7 @@ class Form(object):
         # Merge the items_values with the extra provided values. Extra
         # values will overwrite the item_values.
         values = dict(item_values.items() + values.items())
+        self.merged_data = values
 
         # Set current and previous values of the fields in the form.
         self._set_current_field_data(values)
@@ -327,10 +330,7 @@ class Form(object):
 
         renderer = FormRenderer(self, self._translate)
         form = renderer.render(buttons=buttons, outline=outline)
-        # TODO: Can happen: Error while parsing form in htmlfill: %s. Hint See
-        # 'https://github.com/formencode/formencode/issues/57desc (ti)
-        # <2014-03-21 10:29>
-        return htmlfill.render(form, values)
+        return form
 
     def _add_error(self, fieldname, error):
         field = self.get_field(fieldname)
@@ -493,7 +493,7 @@ class Form(object):
                 values = []
                 db = self._dbsession
                 rel = relation_names[field.name].mapper.class_
-                for v in value:
+                for v in [v for v in value if v != ""]:
                     values.append(db.query(rel).filter(rel.id == int(v)).one())
                 converted = values
             except ValueError:
@@ -572,7 +572,10 @@ class Form(object):
             # already pythonic when loaded from the item.
             converted = unvalidated
         else:
-            self.submitted_data = variabledecode.variable_decode(submitted)
+            try:
+                self.submitted_data = submitted.mixed()
+            except AttributeError:
+                self.submitted_data = submitted
             unvalidated = self.submitted_data
             converted = self.deserialize(unvalidated)
 
@@ -601,8 +604,7 @@ class Form(object):
                 self._add_error(validator._field, validator._error)
 
         # If the form is valid. Save the converted and validated data
-        # into the data dictionary. If not, than save the origin
-        # submitted data.
+        # into the data dictionary.
         has_errors = self.has_errors()
         if not has_errors:
             self.data = converted
@@ -765,8 +767,12 @@ class Field(object):
                 if len(tokens) > 1:
                     key = tokens[0].strip("$")
                     attribute = ".".join(tokens[1:])
+                    # FIXME: This is a bad assumption that there is a
+                    # user within a request. (ti) <2014-07-09 11:18> 
                     if key == "user":
                         tmpitem = self._form._request.user
+                else:
+                    value = self._form.merged_data.get(tokens[0].strip("$"))
                 if tmpitem and not value:
                     value = getattr(tmpitem, attribute)
                     if hasattr(value, '__call__'):
@@ -774,7 +780,7 @@ class Field(object):
             else:
                 value = None
 
-            if value:
+            if value is not None:
                 if isinstance(value, list):
                     value = "[%s]" % ", ".join("'%s'" % unicode(v) for v in value)
                     expr_str = expr_str.replace(x, value)
