@@ -140,6 +140,7 @@ class FormRenderer(Renderer):
         return self.template.render(**values)
 
     def _render_form_buttons(self):
+        _ = self.translate
         html = []
         html.append('<div class="row row-fluid">')
         if len(self._form._config.get_pages()) > 0:
@@ -152,9 +153,9 @@ class FormRenderer(Renderer):
         # form.
         if len(self._form._config._buttons) == 0:
             html.append('<button type="submit" '
-                        'class="btn btn-default">%s</button>' % 'Submit')
+                        'class="btn btn-default">%s</button>' % _('Submit'))
             html.append('<button type="reset" '
-                        'class="btn btn-default">%s</button>' % 'Reset')
+                        'class="btn btn-default">%s</button>' % _('Reset'))
         else:
             for b in self._form._config._buttons:
                 if b.attrib.get("icon"):
@@ -241,8 +242,8 @@ class FieldRenderer(Renderer):
         out = []
         mode = None
         d = difflib.Differ()
-        old = newvalue.split(" ")
-        new = oldvalue.split(" ")
+        old = unicode(newvalue).split(" ")
+        new = unicode(oldvalue).split(" ")
         diff = d.compare(old, new)
         for x in diff:
             if x[0:2] == "+ " and mode != "new":
